@@ -250,7 +250,8 @@ def export_difftests(project, out: str,  rep_info=False, subname=None):
     chrom = list(); start = list(); end = list(); name = list(); bad = list(); ref = list(); alt = list()
     a_ref_counts = list(); b_ref_counts = list()
     a_alt_counts = list(); b_alt_counts = list()
-    ref_es_count = list(); alt_es_count = list()
+    es_count = list()
+    # ref_es_count = list(); alt_es_count = list()
     for ind in tests['ind']:
         t = snvs_a[ind]
         n, r, a = t[0]
@@ -264,17 +265,20 @@ def export_difftests(project, out: str,  rep_info=False, subname=None):
             a_alt_count.append(str(a))
             bads.append(b)
         t1 = np.array(list(map(int, a_ref_count))); t2 = np.array(list(map(int, a_alt_count)))
-        a_es_ref_alt = np.mean(t1 / t2)
-        a_es_alt_ref = np.mean(t2 / t1)
+        # a_es_ref_alt = np.mean(t1 / t2)
+        # a_es_alt_ref = np.mean(t2 / t1)
+        a_es_ref_alt = np.mean(np.log2(t1) - np.log2(t2))
         for _, r, a, b in snvs_b[ind][1:]:
             b_ref_count.append(str(r))
             b_alt_count.append(str(a))
             bads.append(b)
         t1 = np.array(list(map(int, b_ref_count))); t2 = np.array(list(map(int, b_alt_count)))
-        b_es_ref_alt = np.mean(t1 / t2)
-        b_es_alt_ref = np.mean(t2 / t1)
-        ref_es_count.append(np.log2(b_es_ref_alt) - np.log2(a_es_ref_alt))
-        alt_es_count.append(np.log2(b_es_alt_ref) - np.log2(a_es_alt_ref))
+        b_es_ref_alt = np.mean(np.log2(t1) - np.log2(t2))
+        # b_es_ref_alt = np.mean(t1 / t2)
+        # b_es_alt_ref = np.mean(t2 / t1)
+        es_count.append(b_es_ref_alt - a_es_ref_alt)
+        # ref_es_count.append(np.log2(b_es_ref_alt) - np.log2(a_es_ref_alt))
+        # alt_es_count.append(np.log2(b_es_alt_ref) - np.log2(a_es_alt_ref))
         bad.append(sum(bads) / len(bads))
         a_ref_counts.append(','.join(a_ref_count))
         b_ref_counts.append(','.join(b_ref_count))
@@ -288,20 +292,24 @@ def export_difftests(project, out: str,  rep_info=False, subname=None):
     else:
         df = pd.DataFrame({'#chr': chrom, 'start': start, 'end': end, 'mean_bad': bad, 'id': name, 'ref': ref, 'alt': alt })
     diff = pd.concat([df, diff], axis=1)
-    diff['ref_es_count'] = ref_es_count
-    diff['alt_es_count'] = alt_es_count
+    # diff['ref_es_count'] = ref_es_count
+    # diff['alt_es_count'] = alt_es_count
     p_control = diff['ref_p_control']
     p_test = diff['ref_p_test']
     diff['ref_es_p'] = np.log2(p_test) - np.log2(p_control)
-    diff['ref_es_logit'] = np.log2(p_test / (1 - p_test)) - np.log2(p_control / ( 1 - p_control))
+    diff['ref_es_logit'] = np.log2(p_test)  - np.log1p(-p_test) - (np.log2(p_control) - np.log1p(-p_control))
     p_control = diff['alt_p_control']
     p_test = diff['alt_p_test']
     diff['alt_es_p'] = np.log2(p_test) - np.log2(p_control)
-    diff['alt_es_logit'] = np.log2(p_test / (1 - p_test)) - np.log2(p_control / ( 1 - p_control))
+    diff['alt_es_logit'] = np.log2(p_test)  - np.log1p(-p_test) - (np.log2(p_control) - np.log1p(-p_control))
+    t = diff['ref_p_control'] > diff['alt_p_control']
+    diff['preferred_allele_control'] = ['ref' if v else 'alt' for v in t]
+    t = diff['ref_p_test'] > diff['alt_p_test']
+    diff['preferred_allele_test'] = ['ref' if v else 'alt' for v in t]
     t = diff['ref_pval'] < diff['alt_pval']
-    mins = ['ref' if v else 'alt' for v in t]
-    diff['pref_allele'] = mins
-    for col in ['es_count', 'es_p', 'es_logit', 'pval', 'fdr_pval']:
+    diff['scoring_model'] = ['ref|alt' if v else 'alt|ref' for v in t]
+    diff['es_count'] = es_count
+    for col in ['es_p', 'es_logit', 'pval', 'fdr_pval']:
         diff[col] = 0
         diff.loc[t, col] = diff.loc[t, f'ref_{col}']
         diff.loc[~t, col] = diff.loc[~t, f'alt_{col}']
@@ -311,7 +319,6 @@ def export_difftests(project, out: str,  rep_info=False, subname=None):
     diff.to_csv(out, sep='\t', index=None)
 
 
-
 def export_all(name: str, out: str, rep_info: bool = None):
     file = get_init_file(name)
     compression = file.split('.')[-1]
